mgcp

package
v0.7.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 21, 2024 License: MIT Imports: 10 Imported by: 3

Documentation

Index

Constants

const (
	// Update of the list of remote entites supporting the Use Case
	//
	// Use `RemoteEntities` to get the current data
	UseCaseSupportUpdate api.EventType = "ma-mgcp-UseCaseSupportUpdate"

	// Grid maximum allowed feed-in power as percentage value of the cumulated
	// nominal peak power of all electricity producting PV systems was updated
	//
	// Use `PowerLimitationFactor` to get the current data
	//
	// Use Case MGCP, Scenario 2
	DataUpdatePowerLimitationFactor api.EventType = "ma-mgcp-DataUpdatePowerLimitationFactor"

	// Grid momentary power consumption/production data updated
	//
	// Use `Power` to get the current data
	//
	// Use Case MGCP, Scenario 2
	DataUpdatePower api.EventType = "ma-mgcp-DataUpdatePower"

	// Total grid feed in energy data updated
	//
	// Use `EnergyFeedIn` to get the current data
	//
	// Use Case MGCP, Scenario 3
	DataUpdateEnergyFeedIn api.EventType = "ma-mgcp-DataUpdateEnergyFeedIn"

	// Total grid consumed energy data updated
	//
	// Use `EnergyConsumed` to get the current data
	//
	// Use Case MGCP, Scenario 4
	DataUpdateEnergyConsumed api.EventType = "ma-mgcp-DataUpdateEnergyConsumed"

	// Phase specific momentary current consumption/production phase detail data updated
	//
	// Use `CurrentPerPhase` to get the current data
	//
	// Use Case MGCP, Scenario 5
	DataUpdateCurrentPerPhase api.EventType = "ma-mgcp-DataUpdateCurrentPerPhase"

	// Phase specific voltage at the grid connection point
	//
	// Use `VoltagePerPhase` to get the current data
	//
	// Use Case MGCP, Scenario 6
	DataUpdateVoltagePerPhase api.EventType = "ma-mgcp-DataUpdateVoltagePerPhase"

	// Grid frequency data updated
	//
	// Use `Frequency` to get the current data
	//
	// Use Case MGCP, Scenario 7
	DataUpdateFrequency api.EventType = "ma-mgcp-DataUpdateFrequency"
)

Variables

This section is empty.

Functions

This section is empty.

Types

type MGCP

type MGCP struct {
	*usecase.UseCaseBase
}

func NewMGCP

func NewMGCP(localEntity spineapi.EntityLocalInterface, eventCB api.EntityEventCallback) *MGCP

func (*MGCP) AddFeatures

func (e *MGCP) AddFeatures()

func (*MGCP) CurrentPerPhase

func (e *MGCP) CurrentPerPhase(entity spineapi.EntityRemoteInterface) ([]float64, error)

return the momentary current consumption or production at the grid connection point

  • positive values are used for consumption
  • negative values are used for production

func (*MGCP) EnergyConsumed

func (e *MGCP) EnergyConsumed(entity spineapi.EntityRemoteInterface) (float64, error)

return the total consumption energy at the grid connection point

  • positive values are used for consumption

func (*MGCP) EnergyFeedIn

func (e *MGCP) EnergyFeedIn(entity spineapi.EntityRemoteInterface) (float64, error)

return the total feed in energy at the grid connection point

  • negative values are used for production

func (*MGCP) Frequency

func (e *MGCP) Frequency(entity spineapi.EntityRemoteInterface) (float64, error)

return frequency at the grid connection point

func (*MGCP) HandleEvent

func (e *MGCP) HandleEvent(payload spineapi.EventPayload)

handle SPINE events

func (*MGCP) Power

func (e *MGCP) Power(entity spineapi.EntityRemoteInterface) (float64, error)

return the momentary power consumption or production at the grid connection point

  • positive values are used for consumption
  • negative values are used for production

func (*MGCP) PowerLimitationFactor

func (e *MGCP) PowerLimitationFactor(entity spineapi.EntityRemoteInterface) (float64, error)

return the current power limitation factor

possible errors:

  • ErrDataNotAvailable if no such limit is (yet) available
  • and others

func (*MGCP) VoltagePerPhase

func (e *MGCP) VoltagePerPhase(entity spineapi.EntityRemoteInterface) ([]float64, error)

return the voltage phase details at the grid connection point

Jump to